@@ -18,7 +18,7 @@ from homeassistant.helpers.entity import ToggleEntity
 from homeassistant.helpers.entity_component import EntityComponent
 from homeassistant.helpers.restore_state import RestoreEntity
 from homeassistant.loader import bind_hass
-from homeassistant.util.dt import utcnow
+from homeassistant.util.dt import parse_datetime, utcnow
 
 DOMAIN = 'automation'
 ENTITY_ID_FORMAT = DOMAIN + '.{}'
@@ -227,7 +227,9 @@ class AutomationEntity(ToggleEntity, RestoreEntity):
         state = await self.async_get_last_state()
         if state:
             enable_automation = state.state == STATE_ON
-            self._last_triggered = state.attributes.get('last_triggered')
+            last_triggered = state.attributes.get('last_triggered')
+            if last_triggered is not None:
+                self._last_triggered = parse_datetime(last_triggered)
             _LOGGER.debug("Loaded automation %s with state %s from state "
                           " storage last state %s", self.entity_id,
                           enable_automation, state)
